MethodChannelBluetoothClassic class

An implementation of BluetoothClassicPlatform that uses method channels.

Inheritance

Properties

dataReceivedStream → StreamController<Uint8List>
final
deviceDataChannel → EventChannel
final
deviceDiscoveryChannel → EventChannel
The event channel used to receive discovered devices events
final
deviceStatusChannel → EventChannel
final
discoveryStream → StreamController<Device>
user facing stream controller for device discovery
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusStream → StreamController<int>
final

Methods

connect(String address, String serviceUUID) → Future<bool>
override
disconnect() → Future<bool>
override
getPairedDevices() → Future<List<Device>>
override
getPlatformVersion() → Future<String?>
override
initPermissions() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDeviceDataReceived() → Stream<Uint8List>
override
onDeviceDiscovered() → Stream<Device>
override
onDeviceStatusChanged() → Stream<int>
override
startScan() → Future<bool>
override
stopScan() → Future<bool>
override
toString() → String
A string representation of this object.
inherited
write(String message) → Future<bool>
override
writeBytes(Uint8List message) → Future<bool>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited