BluetoothClassicPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BluetoothClassicPlatform
Implementers

Constructors

BluetoothClassicPlatform()
Constructs a BluetoothClassicPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String address, String serviceUUID) → Future<bool>
disconnect() → Future<bool>
getPairedDevices() → Future<List<Device>>
getPlatformVersion() → Future<String?>
initPermissions() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDeviceDataReceived() → Stream<Uint8List>
onDeviceDiscovered() → Stream<Device>
onDeviceStatusChanged() → Stream<int>
startScan() → Future<bool>
stopScan() → Future<bool>
toString() → String
A string representation of this object.
inherited
write(String message) → Future<bool>
writeBytes(Uint8List message) → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ BluetoothClassicPlatform
The default instance of BluetoothClassicPlatform to use.
getter/setter pair